@@ -68,6 +68,17 @@ def patchRotate(item):
             newSetTextAngle = lambda self, angle: originalSetTextAngle(self, angle.AsTenthsOfADegree())
             setattr(newSetTextAngle, "patched", True)
             item.SetTextAngle = newSetTextAngle
+    if hasattr(item, "SetHatchOrientation"):
+        originalSetHatchOrientation = item.SetHatchOrientation
+        if not getattr(originalSetHatchOrientation, "patched", False):
+            newSetHatchOrientation = lambda self, angle: originalSetHatchOrientation(self, angle.AsTenthsOfADegree())
+            setattr(newSetHatchOrientation, "patched", True)
+            item.SetHatchOrientation = newSetHatchOrientation
+
+def pathGetItemDescription(item):
+    if hasattr(item, "GetSelectMenuText") and not hasattr(item, "GetItemDescription"):
+        setattr(item, "GetItemDescription", getattr(item, "GetSelectMenuText"))
+
 
 KICAD_VERSION = getVersion()
 
@@ -179,6 +190,10 @@ if not isV7(KICAD_VERSION):
         setattr(newCalcArcAngles, "patched", True)
         pcbnew.EDA_SHAPE.CalcArcAngles = newCalcArcAngles
 
+    # GetSelectMenuText
+    for x in dir(pcbnew):
+        pathGetItemDescription(getattr(pcbnew, x))
+
     # EDA_TEXT
     originalTextSize = pcbnew.EDA_TEXT.SetTextSize
     pcbnew.EDA_TEXT.SetTextSize = lambda self, size: originalTextSize(self, pcbnew.wxSize(size[0], size[1]))
